@@ -28,7 +28,6 @@ use autodie;
 
 use Date::Format qw(time2str);
 use Email::Valid;
-use Encode qw(decode);
 use List::Util qw(first);
 use List::MoreUtils qw(any uniq);
 use Path::Tiny;
@@ -40,7 +39,6 @@ use Lintian::Inspect::Changelog;
 use Lintian::Inspect::Changelog::Version;
 use Lintian::Relation::Version qw(versions_gt);
 use Lintian::Spelling qw(check_spelling);
-use Lintian::Util qw(strip);
 
 use constant EMPTY => q{};
 
@@ -68,8 +66,11 @@ sub source {
     my $processable = $self->processable;
     my $group = $self->group;
 
-    my @entries = @{$processable->changelog->entries};
+    my $changelog = $processable->changelog;
+    return
+      unless defined $changelog;
 
+    my @entries = @{$changelog->entries};
     return
       unless @entries;
 
@@ -687,16 +688,10 @@ sub binary {
             }
         }
 
-        # We have to decode into UTF-8 to get the right length for the
-        # length check.  For some reason, use open ':utf8' isn't
-        # sufficient.  If the changelog uses a non-UTF-8 encoding,
-        # this will mangle it, but it doesn't matter for the length
-        # check.
-        #
         # Parse::DebianChangelog adds an additional space to the
         # beginning of each line, so we have to adjust for that in the
         # length check.
-        my @lines = split("\n", decode('utf-8', $changes));
+        my @lines = split(/\n/, $changes);
         for my $i (0 .. $#lines) {
             my $line = $i + $chloff;
             $self->tag('debian-changelog-line-too-short', $1, "(line $line)")
