@@ -24,8 +24,9 @@
 
 package Lintian::fields::architecture;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::Compare;
@@ -68,7 +69,7 @@ sub files {
       if $file->name =~ m,^usr/lib/R/.*/DESCRIPTION,
       && !$file->is_dir
       && $self->package =~ /^r-(?:cran|bioc|other)-/
-      && $file->slurp =~ m/NeedsCompilation: no/m
+      && $file->bytes =~ m/NeedsCompilation: no/m
       && $self->architecture ne 'all';
 
     return;
