@@ -20,12 +20,12 @@
 
 package Lintian::files::embedded_libraries;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Lintian::SlidingWindow;
-use Lintian::Util qw(strip);
 
 use Moo;
 use namespace::clean;
@@ -41,15 +41,27 @@ sub load_file_package_list_mapping {
         $datafile,
         qr/\s*\~\~\s*/,
         sub {
-            my $pkg = strip($_[0]);
+            my ($pkg) = @_;
+
+            # trim both ends
+            $pkg =~ s/^\s+|\s+$//g;
+
             my $pkg_regexp = qr/^$pkg$/x;
             my @sliptline = split(/\s*\~\~/, $_[1], 2);
-            my $file_regexp = strip($sliptline[0]);
+            my $file_regexp = $sliptline[0];
+
+            # trim both ends
+            $file_regexp =~ s/^\s+|\s+$//g;
+
             $file_regexp =~ s/\$EXT/$ext/g;
             my $recontents = $reinside;
 
             if (scalar(@sliptline) == 2) {
-                my $contents = strip($sliptline[1]);
+                my $contents = $sliptline[1];
+
+                # trim both ends
+                $contents =~ s/^\s+|\s+$//g;
+
                 $recontents = qr/$contents/;
             }
 
@@ -126,7 +138,7 @@ sub files {
 
                     if(defined $reinside) {
                         my $foundre = 0;
-                        my $fd = $file->open(':raw');
+                        open(my $fd, '<:raw', $file->unpacked_path);
                         my $sfd = Lintian::SlidingWindow->new($fd);
 
                       READWINDOW:
@@ -153,7 +165,7 @@ sub files {
     if (    $file->name =~ m,/feedparser\.py$,
         and $self->processable->source ne 'feedparser'){
 
-        my $fd = $file->open;
+        open(my $fd, '<', $file->unpacked_path);
         while (<$fd>) {
 
             if (m,Universal feed parser,) {
