@@ -20,10 +20,9 @@
 
 package Lintian::includes::config_h;
 
-use strict;
+use v5.20;
 use warnings;
-
-use Path::Tiny;
+use utf8;
 
 use Moo;
 use namespace::clean;
@@ -42,10 +41,7 @@ sub files {
     return
       unless $file->name =~ m{/config.h$};
 
-    return
-      unless $file->is_open_ok;
-
-    my $contents = path($file->fs_path)->slurp;
+    my $contents = $file->bytes;
 
     $self->tag('package-name-defined-in-config-h', $file->name)
       if $contents =~ m{\bPACKAGE_NAME\b};
