@@ -20,8 +20,9 @@
 
 package Lintian::modprobe;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::MoreUtils qw(uniq);
@@ -42,7 +43,7 @@ sub files {
     } elsif ($file->name =~ m,^etc/modprobe\.d/(.+)$,
         or $file->name =~ m,^etc/modules-load\.d/(.+)$,) {
 
-        my @obsolete = uniq($file->slurp =~ /^\s*(install|remove)/mg);
+        my @obsolete = uniq($file->bytes =~ /^\s*(install|remove)/mg);
         $self->tag('obsolete-command-in-modprobe.d-file', $file->name, $_)
           for @obsolete;
     }
