@@ -20,11 +20,12 @@
 
 package Lintian::triggers;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
+use autodie qw(open);
 
 use Lintian::Data;
-use Lintian::Util qw(internal_error strip);
 
 use Moo;
 use namespace::clean;
@@ -39,12 +40,9 @@ sub _parse_trigger_types {
         $values{$k} = $v;
     }
     if (exists($values{'implicit-await'})) {
-        internal_error(
-            join(q{ },
-                'Invalid trigger-types data file:',
-                "$key is defined as implicit-await trigger,",
-                'but is not defined as an await trigger')
-        ) if $values{'implicit-await'} and not $values{'await'};
+        die
+"Invalid trigger-types: $key is defined as implicit-await but not await"
+          if $values{'implicit-await'} and not $values{'await'};
     }
     return \%values;
 }
@@ -52,17 +50,20 @@ sub _parse_trigger_types {
 my $TRIGGER_TYPES = Lintian::Data->new('triggers/trigger-types',
     qr/\s*\Q=>\E\s*/, \&_parse_trigger_types);
 
-sub always {
+sub installable {
     my ($self) = @_;
 
     my $processable = $self->processable;
 
     my $triggers_file = $processable->control->lookup('triggers');
     return if not $triggers_file or not $triggers_file->is_open_ok;
-    my $fd = $triggers_file->open;
+    open(my $fd, '<', $triggers_file->unpacked_path);
     my %seen_triggers;
     while (my $line = <$fd>) {
-        strip($line);
+
+        # trim both ends
+        $line =~ s/^\s+|\s+$//g;
+
         next if $line =~ m/^(?:\s*)(?:#.*)?$/;
         my ($trigger_type, $arg) = split(m/\s++/, $line, 2);
         my $trigger_info = $TRIGGER_TYPES->value($trigger_type);
