@@ -20,8 +20,9 @@
 
 package Lintian::upstream_signature;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Path::Tiny;
 use List::Util qw(none);
@@ -47,7 +48,7 @@ sub source {
 
     # in uscan's gittag mode,signature will never match
     my $watch = $processable->patched->resolve_path('debian/watch');
-    my $gittag = $watch && $watch->file_contents =~ m/pgpmode=gittag/;
+    my $gittag = $watch && $watch->bytes =~ /pgpmode=gittag/;
 
     my @filenames = sort keys %{$processable->files};
     my @origtar
