@@ -18,8 +18,9 @@
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301, USA.
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Getopt::Long();
@@ -27,15 +28,15 @@ use File::Basename qw(basename);
 use YAML::XS ();
 use MIME::Base64 qw(encode_base64);
 
-use Lintian::Lab;
+use Lintian::Deb822Parser qw(visit_dpkg_paragraph);
 use Lintian::Relation::Version qw(versions_comparator);
-use Lintian::Util qw(
+use Lintian::Reporting::Util qw(
   find_backlog
   load_state_cache
-  open_gz
   save_state_cache
-  strip
-  visit_dpkg_paragraph
+);
+use Lintian::Util qw(
+  open_gz
 );
 
 my $DEFAULT_CHECKSUM = 'sha256';
@@ -323,7 +324,7 @@ sub cleanup_group_state {
         exists($group_data->{'processing-errors'})
         and (not exists($group_data->{'last-error-by'})
             or $group_data->{'last-error-by'} ne $OPT{'desired-version'})
-      ) {
+    ) {
         log_debug(
             "Clearing error-counter for ${group_id}: New version of lintian");
         delete($group_data->{'processing-errors'});
@@ -365,7 +366,10 @@ sub _parse_srcs_pg {
     return unless $ACTIVE_GROUPS{$group_id};
     $dir .= '/' if $dir;
     foreach my $f (split m/\n/, $paragraph->{"checksums-${DEFAULT_CHECKSUM}"}){
-        strip($f);
+
+        # trim both ends
+        $f =~ s/^\s+|\s+$//g;
+
         next unless $f && $f =~ m/\.dsc$/;
         my ($checksum, undef, $basename) = split(m/\s++/, $f);
         my $b64_checksum = encode_base64(pack('H*', $checksum));
