@@ -18,8 +18,9 @@
 
 package Lintian::Output::Standard;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use HTML::Entities;
 use Term::ANSIColor ();
