@@ -22,8 +22,9 @@
 
 package Lintian::Util;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Carp qw(croak);
@@ -34,8 +35,10 @@ use IO::Async::Loop;
 use IO::Async::Process;
 use Path::Tiny;
 use POSIX qw(sigprocmask SIG_BLOCK SIG_UNBLOCK SIG_SETMASK);
+use Unicode::UTF8 qw(valid_utf8);
 
-use Lintian::Deb822Parser qw(read_dpkg_control parse_dpkg_control);
+use Lintian::Deb822Parser
+  qw(read_dpkg_control parse_dpkg_control parse_dpkg_control_string);
 
 # Force export as soon as possible, since some of the modules we load also
 # depend on us and the sequencing can cause things not to be exported
@@ -53,18 +56,12 @@ BEGIN {
     @EXPORT_OK = (qw(
           get_deb_info
           get_dsc_info
+          get_dsc_info_from_string
           get_file_checksum
           get_file_digest
-          file_is_encoded_in_non_utf8
-          is_string_utf8_encoded
-          fail
-          internal_error
           do_fork
           run_cmd
           safe_qx
-          strip
-          lstrip
-          rstrip
           copy_dir
           human_bytes
           gunzip_file
@@ -74,16 +71,11 @@ BEGIN {
           check_path
           clean_env
           normalize_pkg_path
-          parse_boolean
           is_ancestor_of
           locate_helper_tool
           drain_pipe
-          signal_number2name
           drop_relative_prefix
-          dequote_name
-          pipe_tee
           read_md5sums
-          untaint
           $PKGNAME_REGEX
           $PKGREPACK_REGEX
           $PKGVERSION_REGEX
@@ -292,9 +284,10 @@ sub get_deb_info {
     my $composite = Future->needs_all($dpkgfuture, $tarfuture);
     $composite->get;
 
-    open(my $fh, '<', \$control);
-    my @data = parse_dpkg_control($fh);
-    close $fh;
+    return {}
+      unless valid_utf8($control);
+
+    my @data = parse_dpkg_control_string($control);
 
     return $data[0];
 }
@@ -317,8 +310,22 @@ L</read_dpkg_control(FILE[, FLAGS[, LINES]])> do.
 
 sub get_dsc_info {
     my ($file) = @_;
+
     my @data = read_dpkg_control($file);
-    return (defined($data[0])? $data[0] : undef);
+
+    return $data[0];
+}
+
+=item get_dsc_info_from_string (STRING)
+
+=cut
+
+sub get_dsc_info_from_string {
+    my ($text) = @_;
+
+    my @data = parse_dpkg_control_string($text);
+
+    return $data[0];
 }
 
 =item drain_pipe(FD)
@@ -389,54 +396,6 @@ sub get_file_checksum {
     return $digest->hexdigest;
 }
 
-=item is_string_utf8_encoded(STRING)
-
-Returns a truth value if STRING can be decoded as valid UTF-8.
-
-=cut
-
-{
-    my $decoder = Encode::find_encoding('UTF-8');
-    die('No UTF-8 decoder !?') unless ref($decoder);
-
-    sub is_string_utf8_encoded {
-        my ($str) = @_;
-        if ($str =~ m,\e[-!"\$%()*+./],) {
-            # ISO-2022
-            return 0;
-        }
-        eval {$decoder->decode($str, Encode::FB_CROAK);};
-        if ($@) {
-            # fail
-            return 0;
-        }
-        # pass
-        return 1;
-    }
-}
-
-=item file_is_encoded_in_non_utf8 (...)
-
-Undocumented
-
-=cut
-
-sub file_is_encoded_in_non_utf8 {
-    my ($file) = @_;
-
-    open(my $fd, '<', $file);
-    my $line = 0;
-    while (<$fd>) {
-        if (!is_string_utf8_encoded($_)) {
-            $line = $.;
-            last;
-        }
-    }
-    close($fd);
-
-    return $line;
-}
-
 =item do_fork()
 
 Overrides fork to reset signal handlers etc. in the child.
@@ -854,41 +813,6 @@ sub gzip {
     return;
 }
 
-=item internal_error (MSG[, ...])
-
-Use to signal an internal error. The argument(s) will used to print a
-diagnostic message to the user.
-
-If multiple arguments are given, they will be merged into a single
-string (by join (' ', @_)).  If only one argument is given it will be
-stringified and used directly.
-
-=item fail (MSG[, ...])
-
-Deprecated alias of "internal_error".
-
-=cut
-
-sub fail {
-    warnings::warnif('deprecated',
-        '[deprecation] fail() has been replaced by internal_error()');
-    goto \&internal_error;
-}
-
-sub internal_error {
-    my $str = 'internal error: ';
-    if (@_) {
-        $str .= join ' ', @_;
-    } else {
-        if ($!) {
-            $str .= "$!";
-        } else {
-            $str .= 'No context.';
-        }
-    }
-    croak $str;
-}
-
 =item locate_helper_tool(TOOLNAME)
 
 Given the name of a helper tool, returns the path to it.  The tool
@@ -909,7 +833,7 @@ If the tool cannot be found, this sub will cause a trappable error.
     sub locate_helper_tool {
         my ($toolname) = @_;
         if ($toolname =~ m{(?:\A|/) \.\. (?:\Z|/)}xsm) {
-            internal_error("$toolname is not a valid tool name");
+            croak "$toolname is not a valid tool name";
         }
         return $_CACHE{$toolname} if exists $_CACHE{$toolname};
 
@@ -926,79 +850,11 @@ If the tool cannot be found, this sub will cause a trappable error.
             }
         }
         $toolpath_str //= '<N/A>';
-        internal_error(
-            sprintf(
-                'Cannot locate %s (search dirs: %s)',
-                $toolname, $toolpath_str
-            ));
+
+        croak "Cannot locate $toolname (search dirs: $toolpath_str)";
     }
 }
 
-=item strip ([LINE])
-
-Strips whitespace from the beginning and the end of LINE and returns
-it.  If LINE is omitted, C<$_> will be used instead. Example
-
- @lines = map { strip } <$fd>;
-
-In void context, the input argument will be modified so it can be
-used as a replacement for chomp in some cases:
-
-  while ( my $line = <$fd> ) {
-    strip ($line);
-    # $line no longer has any leading or trailing whitespace
-  }
-
-Otherwise, a copy of the string is returned:
-
-  while ( my $orig = <$fd> ) {
-    my $stripped = strip ($orig);
-    if ($stripped ne $orig) {
-        # $orig had leading or/and trailing whitespace
-    }
-  }
-
-=item lstrip ([LINE])
-
-Like L<strip|/strip ([LINE])> but only strip leading whitespace.
-
-=item rstrip ([LINE])
-
-Like L<strip|/strip ([LINE])> but only strip trailing whitespace.
-
-=cut
-
-# prototype for default to $_
-sub strip (_) { ## no critic (Subroutines::RequireFinalReturn)
-    if (defined wantarray) {
-        # perl 5.14 s///r would have been useful here.
-        my ($arg) = @_;
-        $arg =~ s/^\s++//;
-        # unpack 'A*' is faster than s/\s++$//
-        return unpack('A*', $arg);
-    }
-    $_[0] =~ s/^\s++//;
-    $_[0] = unpack('A*', $_[0]);
-    # void context, so no return needed here.
-}
-
-# prototype for default to $_
-sub lstrip (_) { ## no critic (Subroutines::RequireFinalReturn)
-    if (defined wantarray) {
-        # perl 5.14 s///r would have been useful here.
-        my ($arg) = @_;
-        $arg =~ s/^\s++//;
-        return $arg;
-    }
-    $_[0] =~ s/^\s++//;
-    # void context, so no return needed here.
-}
-
-{
-    no warnings qw(once);
-    *rstrip = \&Lintian::Deb822Parser::rstrip;
-}
-
 =item check_path (CMD)
 
 Returns 1 if CMD can be found in PATH (i.e. $ENV{PATH}) and is
@@ -1032,30 +888,6 @@ sub drop_relative_prefix {
     return $copy;
 }
 
-=item dequote_name(STR, REMOVESLASH)
-
-Strip an extra layer quoting in index file names and optionally
-remove an initial "./" if any.
-
-Remove initial ./ by default
-
-=cut
-
-sub dequote_name {
-    my ($name, $slsd) = @_;
-    return
-      unless defined $name;
-    $slsd = 1 unless defined $slsd;
-    $name =~ s,^\.?/,, if $slsd;
-    # Optimise for the case where the filename does not contain
-    # backslashes.  It is a fairly rare to see that in practise.
-    if (index($name, '\\') > -1) {
-        $name =~ s/(\G|[^\\](?:\\\\)*)\\(\d{3})/"$1" . chr(oct $2)/ge;
-        $name =~ s/\\\\/\\/g;
-    }
-    return $name;
-}
-
 =item signal_number2name(NUM)
 
 Given a number, returns the name of the signal (without leading
@@ -1187,38 +1019,6 @@ sub normalize_pkg_path {
     return join('/', @normalised);
 }
 
-=item parse_boolean (STR)
-
-Attempt to parse STR as a boolean and return its value.
-If STR is not a valid/recognised boolean, the sub will
-invoke croak.
-
-The following values recognised (string checks are not
-case sensitive):
-
-=over 4
-
-=item The integer 0 is considered false
-
-=item Any non-zero integer is considered true
-
-=item "true", "y" and "yes" are considered true
-
-=item "false", "n" and "no" are considered false
-
-=back
-
-=cut
-
-sub parse_boolean {
-    my ($str) = @_;
-    return $str == 0 ? 0 : 1 if $str =~ m/^-?\d++$/o;
-    $str = lc $str;
-    return 1 if $str eq 'true' or $str =~ m/^y(?:es)?$/;
-    return 0 if $str eq 'false' or $str =~ m/^no?$/;
-    croak "\"$str\" is not a valid boolean value";
-}
-
 =item is_ancestor_of(PARENTDIR, PATH)
 
 Returns true if and only if PATH is PARENTDIR or a path stored
@@ -1250,66 +1050,6 @@ sub is_ancestor_of {
     return 0;
 }
 
-=item pipe_tee(INHANDLE, OUTHANDLES[, OPTS])
-
-Read bytes from INHANDLE and copy them into all of the handles in the
-listref OUTHANDLES. The optional OPTS argument is a hashref of
-options, see below.
-
-The subroutine will continue to read from INHANDLE until it is
-exhausted or an error occurs (either during read or write).  In case
-of errors, a trappable error will be raised.  The handles are left
-open when the subroutine returns, caller must close them afterwards.
-
-Caller should ensure that handles are using "blocking" I/O.  The
-subroutine will use L<sysread|perlfunc/sysread> and
-L<syswrite|perlfunc/syswrite> when reading and writing.
-
-
-OPTS, if given, may contain the following key-value pairs:
-
-=over 4
-
-=item chunk_size
-
-A suggested buffer size for read/write.  If given, it will be to
-sysread as LENGTH argument when reading from INHANDLE.
-
-=back
-
-=cut
-
-sub pipe_tee {
-    my ($in_fd, $out_ref, $opts) = @_;
-    my $read_size = ($opts && $opts->{'chunk_size'}) // 8096;
-    my @outs = @{$out_ref};
-    my $buffer;
-    while (1) {
-        # Disable autodie, because it includes the buffer
-        # exception.  Said buffer will get printed on errors
-        # yielding completely unreadable errors and a terminal
-        # drowned in binary characters.
-        no autodie qw(sysread syswrite);
-        my $rlen = sysread($in_fd, $buffer, $read_size);
-        if (not $rlen) {
-            last if defined($rlen);
-            croak("Failed to read from input handle: $!");
-        }
-        for my $out_fd (@outs) {
-            my $written = 0;
-            while ($written < $rlen) {
-                my $remain = $rlen - $written;
-                my $res = syswrite($out_fd, $buffer, $remain,$written);
-                if (!defined($res)) {
-                    croak("Failed to write to output handle: $!");
-                }
-                $written += $res;
-            }
-        }
-    }
-    return 1;
-}
-
 =item read_md5sums
 
 =item unescape_md5sum_filename
@@ -1358,28 +1098,35 @@ sub unescape_md5sum_filename {
 sub read_md5sums {
     my ($text) = @_;
 
-    # make a local copy
-    my $buffer = $text;
-
     my %checksums;
     my @errors;
 
-  TRY_AGAIN:
+    my @lines = split(/\n/, $text);
 
     # start with checksum; processing style inspired by IO::Async::Stream
-    while ($buffer =~ s/^((?:\\)?\S{32}) [ *]//) {
+    while (defined(my $line = shift @lines)) {
+
+        next
+          unless length $line;
+
+        # make sure there are two spaces in between
+        $line =~ /^((?:\\)?\S{32})  (.*)$/;
 
         my $checksum = $1;
+        my $string = $2;
+
+        unless (length $checksum && length $string) {
+
+            push(@errors, "Odd text: $line");
+            next;
+        }
+
         my $problematic = 0;
 
         # leading slash in checksum indicates an escaped name
         $problematic = 1
           if $checksum =~ s{^\\}{};
 
-        # read up until the next newline
-        $buffer =~ s/^([^\n]+)\n//;
-        my $string = $1;
-
         my $path = unescape_md5sum_filename($string, $problematic);
 
         push(@errors, "Empty name for checksum $checksum")
@@ -1388,31 +1135,9 @@ sub read_md5sums {
         $checksums{$path} = $checksum;
     }
 
-    if ($buffer =~ s/([^\n]*)(?:\n|\z)//) {
-        my $unreadable = $1;
-
-        # this skips empty lines
-        push(@errors, "Odd text: $unreadable")
-          if length $unreadable;
-
-        goto TRY_AGAIN
-          if length $buffer;
-    }
-
     return (\%checksums, \@errors);
 }
 
-=item untaint(VALUE)
-
-Untaint VALUE
-
-=cut
-
-sub untaint {
-    return $_[0] = $1 if $_[0] =~ m/^(.*)$/;
-    return;
-}
-
 =back
 
 =head1 SEE ALSO
