@@ -49,8 +49,9 @@ errors.
 
 =cut
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 my $CLASS = __PACKAGE__;
 my $PROFILE;
@@ -72,20 +73,19 @@ use File::Basename qw(basename);
 use File::Find ();
 use List::MoreUtils qw{any};
 use Path::Tiny;
+use Unicode::UTF8 qw(valid_utf8 decode_utf8);
 
 use Lintian::Spelling qw(check_spelling);
 use Lintian::Data;
-use Lintian::Deb822Parser qw(read_dpkg_control);
+use Lintian::Deb822Parser qw(parse_dpkg_control_string);
 use Lintian::Profile;
 use Lintian::Tag::Info;
-use Lintian::Util qw(is_string_utf8_encoded);
 
 # We want data files loaded early to avoid problems with missing data
 # files ending up in releases (like in 2.5.17 and 2.5.18).
 $Lintian::Data::LAZY_LOAD = 0;
 
 my %severities = map { $_ => 1 } @Lintian::Tag::Info::SEVERITIES;
-my %certainties = map { $_ => 1 } @Lintian::Tag::Info::CERTAINTIES;
 my %check_types = map { $_ => 1 } qw(binary changes source udeb);
 my %known_html_tags = map { $_ => 1 } qw(a em i tt);
 
@@ -144,7 +144,7 @@ translations.  Otherwise, they must be regular checks.
 =cut
 
 sub test_check_desc {
-    my ($opts, @descs);
+    my ($opts, @dirs);
     my $builder = $CLASS->builder;
     my $colldir = '/usr/share/lintian/collection';
     my $find_opt = {'filter' => undef,};
@@ -155,12 +155,19 @@ sub test_check_desc {
         $find_opt->{'filter'} = $opts->{'filter'} if exists $opts->{'filter'};
     }
     $opts //= {};
-    @descs = @_;
+    @dirs = @_;
     load_profile_for_test();
 
-    foreach my $desc_file (map { _find_check($find_opt, $_) } @descs) {
+    my @descs = map { _find_check($find_opt, $_) } @dirs;
+    foreach my $desc_file (@descs) {
         my ($header, @tagpara);
-        eval {($header, @tagpara) = read_dpkg_control($desc_file);};
+        my $bytes = path($desc_file)->slurp;
+        $builder->ok(valid_utf8($bytes),
+            "File $desc_file does not use a national encoding.");
+        next
+          unless valid_utf8($bytes);
+        my $contents = decode_utf8($bytes);
+        eval {($header, @tagpara) = parse_dpkg_control_string($contents);};
         if (my $err = $@) {
             $err =~ s/ at .*? line \d+\s*\n//;
             $builder->ok(0, "Cannot parse $desc_file");
@@ -203,7 +210,6 @@ sub test_check_desc {
         foreach my $tpara (@tagpara) {
             my $tag = $tpara->{'tag'}//'';
             my $severity = $tpara->{'severity'}//'';
-            my $certainty = $tpara->{'certainty'}//'';
             my $info = $tpara->{'info'} // '';
             my (@htmltags, %seen);
 
@@ -218,13 +224,10 @@ sub test_check_desc {
             $builder->cmp_ok(length $tag, '<=', 68, 'Tag is not too long')
               or $builder->diag("$cname: $tag\n");
 
-            # Severity / Certainty
+            # Severity
             $builder->ok($severity && exists $severities{$severity},
                 'Tag has valid severity')
               or $builder->diag("$cname: $tag severity: $severity\n");
-            $builder->ok($certainty && exists $certainties{$certainty},
-                'Tag has valid certainty')
-              or $builder->diag("$cname: $tag certainty: $certainty\n");
 
             # Info
             my $mistakes = 0;
@@ -254,10 +257,8 @@ sub test_check_desc {
                 'Tag info uses only two spaces after a full stop')
               or $builder->diag("$content_type $cname: $tag ($1)\n");
 
-            $builder->ok(
-                is_string_utf8_encoded($info),
-                'Tag info must be written in UTF-8'
-            ) or $builder->diag("$content_type $cname: $tag\n");
+            $builder->ok(valid_utf8($info),'Tag info must be written in UTF-8')
+              or $builder->diag("$content_type $cname: $tag\n");
 
             # Check the tag info for unescaped <> or for unknown tags (which
             # probably indicate the same thing).
@@ -397,15 +398,17 @@ sub test_load_checks {
         my $find_opt = {'want-check-name' => 1,};
         $find_opt->{'filter'} = $opts->{'filter'} if exists $opts->{'filter'};
         @checknames = _find_check($find_opt, $dir);
-        $builder->cmp_ok(scalar @checknames, '>', 0, 'Found checks to test');
     } else {
         $builder->skip('Given an explicit list of checks');
     }
 
+    $builder->skip('No desc files found')
+      unless @checknames;
+
     load_profile_for_test();
 
     foreach my $checkname (@checknames) {
-        my $cs = Lintian::CheckScript->new;
+        my $cs = Lintian::Check::Info->new;
         $cs->basedir($dir);
         $cs->name($checkname);
         eval {$cs->load;};
@@ -441,7 +444,10 @@ sub test_load_checks {
 
         # setup and breakdown should only be used together with files
         my $has_entrypoint = any { $ppkg->can($_) }
-        ('source', 'binary', 'udeb', 'changes', 'always', 'files');
+        (
+            'source', 'binary', 'udeb', 'installable',
+            'changes', 'always', 'files'
+        );
 
         if (!$builder->ok($has_entrypoint, "Check $cname has entry point")) {
             $builder->diag("Expected package name is $ppkg\n");
@@ -532,7 +538,6 @@ sub test_tags_implemented {
         my $find_opt = {'want-check-name' => 1,};
         $find_opt->{'filter'} = $opts->{'filter'} if exists $opts->{'filter'};
         @checknames = _find_check($find_opt, $dir);
-        $builder->cmp_ok(scalar @checknames, '>', 0, 'Found checks to test');
     } else {
         $builder->skip('Given an explicit list of checks');
     }
@@ -547,7 +552,7 @@ sub test_tags_implemented {
 
     foreach my $checkname (@checknames) {
         my (@tags, $codestr, @missing);
-        my $cs = Lintian::CheckScript->new;
+        my $cs = Lintian::Check::Info->new;
         $cs->basedir($dir);
         $cs->name($checkname);
         eval {$cs->load;};
